﻿using System;
using System.Threading.Tasks;
using IgniteUI.Blazor.Controls;
using Infragistics.Samples.Data;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Components.Web;

namespace Infragistics.Samples.ViewModel
{
    public class DemoViewModel : ComponentBase
    {
        [Inject]
        protected IIgniteUIBlazor IgniteUIBlazor { get; set; }

        public RangeCollection<PositionData> DataSource { get; } = new RangeCollection<PositionData>();

        public GeographicMap MyGeoMap { get; set; }

        public ValueBrushScale ColorScale { get; set; }
        public SizeScale SeriesSizeScale{ get; set; }

        protected override void OnInitialized()
        {
            GeographicMapModule.Register(IgniteUIBlazor);
            DataChartInteractivityModule.Register(IgniteUIBlazor);
            SetUpScales();
            DataSource.ReplaceCollection(DemoData.BuildData());
        }

        protected override async Task OnAfterRenderAsync(bool firstRender)
        {
            await SetUpMap();
        }

        public void RefreshButtonClick(MouseEventArgs obj)
        {
            DataSource.ReplaceCollection(DemoData.BuildData());
        }
        
        public async Task SetUpMap()
        {
            var width = 0.04255831475445859;
            var height = 0.01697716558750315;
            var left = -92.38611101691961;
            var top = 29.72555428685662;
            var rect = new Rect(left, top, width, height);

            await MyGeoMap.EnsureReady();
            await MyGeoMap.ZoomToGeographicAsync(rect);

        }

        public void SetUpScales()
        {
            ColorScale = new ValueBrushScale
            {
                Brushes = "#FFE5E5,#FF0000,#660000",
                MinimumValue = 0,
                MaximumValue = 3352.427,
            };
            SeriesSizeScale = new SizeScale
            {
                MinimumValue = 8,
                MaximumValue = 56,
            };
        }
    }
}
